Documentation
¶
Overview ¶
Example ¶
package main
import (
"bramp.net/antlr4/dot"
"fmt"
"github.com/antlr/antlr4/runtime/Go/antlr"
)
type exampleListener struct {
*dot.BaseDOTListener
}
func (l *exampleListener) EnterEveryRule(ctx antlr.ParserRuleContext) {
fmt.Println(ctx.GetText())
}
func main() {
// Setup the input
is := antlr.NewInputStream("...some text to parse...")
// Create the Lexer
lexer := dot.NewDOTLexer(is)
stream := antlr.NewCommonTokenStream(lexer, antlr.TokenDefaultChannel)
// Create the Parser
p := dot.NewDOTParser(stream)
p.BuildParseTrees = true
p.AddErrorListener(antlr.NewDiagnosticErrorListener(true))
// Finally walk the tree
tree := p.Graph()
antlr.ParseTreeWalkerDefault.Walk(&exampleListener{}, tree)
}
Index ¶
- Constants
- type A_listContext
- func (s *A_listContext) AllId() []IIdContext
- func (s *A_listContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *A_listContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *A_listContext) GetParser() antlr.Parser
- func (s *A_listContext) GetRuleContext() antlr.RuleContext
- func (s *A_listContext) Id(i int) IIdContext
- func (*A_listContext) IsA_listContext()
- func (s *A_listContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type Attr_listContext
- func (s *Attr_listContext) A_list(i int) IA_listContext
- func (s *Attr_listContext) AllA_list() []IA_listContext
- func (s *Attr_listContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *Attr_listContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *Attr_listContext) GetParser() antlr.Parser
- func (s *Attr_listContext) GetRuleContext() antlr.RuleContext
- func (*Attr_listContext) IsAttr_listContext()
- func (s *Attr_listContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type Attr_stmtContext
- func (s *Attr_stmtContext) Attr_list() IAttr_listContext
- func (s *Attr_stmtContext) EDGE() antlr.TerminalNode
- func (s *Attr_stmtContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *Attr_stmtContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *Attr_stmtContext) GRAPH() antlr.TerminalNode
- func (s *Attr_stmtContext) GetParser() antlr.Parser
- func (s *Attr_stmtContext) GetRuleContext() antlr.RuleContext
- func (*Attr_stmtContext) IsAttr_stmtContext()
- func (s *Attr_stmtContext) NODE() antlr.TerminalNode
- func (s *Attr_stmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type BaseDOTListener
- func (s *BaseDOTListener) EnterA_list(ctx *A_listContext)
- func (s *BaseDOTListener) EnterAttr_list(ctx *Attr_listContext)
- func (s *BaseDOTListener) EnterAttr_stmt(ctx *Attr_stmtContext)
- func (s *BaseDOTListener) EnterEdgeRHS(ctx *EdgeRHSContext)
- func (s *BaseDOTListener) EnterEdge_stmt(ctx *Edge_stmtContext)
- func (s *BaseDOTListener) EnterEdgeop(ctx *EdgeopContext)
- func (s *BaseDOTListener) EnterEveryRule(ctx antlr.ParserRuleContext)
- func (s *BaseDOTListener) EnterGraph(ctx *GraphContext)
- func (s *BaseDOTListener) EnterId(ctx *IdContext)
- func (s *BaseDOTListener) EnterNode_id(ctx *Node_idContext)
- func (s *BaseDOTListener) EnterNode_stmt(ctx *Node_stmtContext)
- func (s *BaseDOTListener) EnterPort(ctx *PortContext)
- func (s *BaseDOTListener) EnterStmt(ctx *StmtContext)
- func (s *BaseDOTListener) EnterStmt_list(ctx *Stmt_listContext)
- func (s *BaseDOTListener) EnterSubgraph(ctx *SubgraphContext)
- func (s *BaseDOTListener) ExitA_list(ctx *A_listContext)
- func (s *BaseDOTListener) ExitAttr_list(ctx *Attr_listContext)
- func (s *BaseDOTListener) ExitAttr_stmt(ctx *Attr_stmtContext)
- func (s *BaseDOTListener) ExitEdgeRHS(ctx *EdgeRHSContext)
- func (s *BaseDOTListener) ExitEdge_stmt(ctx *Edge_stmtContext)
- func (s *BaseDOTListener) ExitEdgeop(ctx *EdgeopContext)
- func (s *BaseDOTListener) ExitEveryRule(ctx antlr.ParserRuleContext)
- func (s *BaseDOTListener) ExitGraph(ctx *GraphContext)
- func (s *BaseDOTListener) ExitId(ctx *IdContext)
- func (s *BaseDOTListener) ExitNode_id(ctx *Node_idContext)
- func (s *BaseDOTListener) ExitNode_stmt(ctx *Node_stmtContext)
- func (s *BaseDOTListener) ExitPort(ctx *PortContext)
- func (s *BaseDOTListener) ExitStmt(ctx *StmtContext)
- func (s *BaseDOTListener) ExitStmt_list(ctx *Stmt_listContext)
- func (s *BaseDOTListener) ExitSubgraph(ctx *SubgraphContext)
- func (s *BaseDOTListener) VisitErrorNode(node antlr.ErrorNode)
- func (s *BaseDOTListener) VisitTerminal(node antlr.TerminalNode)
- type DOTLexer
- type DOTListener
- type DOTParser
- func (p *DOTParser) A_list() (localctx IA_listContext)
- func (p *DOTParser) Attr_list() (localctx IAttr_listContext)
- func (p *DOTParser) Attr_stmt() (localctx IAttr_stmtContext)
- func (p *DOTParser) EdgeRHS() (localctx IEdgeRHSContext)
- func (p *DOTParser) Edge_stmt() (localctx IEdge_stmtContext)
- func (p *DOTParser) Edgeop() (localctx IEdgeopContext)
- func (p *DOTParser) Graph() (localctx IGraphContext)
- func (p *DOTParser) Id() (localctx IIdContext)
- func (p *DOTParser) Node_id() (localctx INode_idContext)
- func (p *DOTParser) Node_stmt() (localctx INode_stmtContext)
- func (p *DOTParser) Port() (localctx IPortContext)
- func (p *DOTParser) Stmt() (localctx IStmtContext)
- func (p *DOTParser) Stmt_list() (localctx IStmt_listContext)
- func (p *DOTParser) Subgraph() (localctx ISubgraphContext)
- type EdgeRHSContext
- func (s *EdgeRHSContext) AllEdgeop() []IEdgeopContext
- func (s *EdgeRHSContext) AllNode_id() []INode_idContext
- func (s *EdgeRHSContext) AllSubgraph() []ISubgraphContext
- func (s *EdgeRHSContext) Edgeop(i int) IEdgeopContext
- func (s *EdgeRHSContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *EdgeRHSContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *EdgeRHSContext) GetParser() antlr.Parser
- func (s *EdgeRHSContext) GetRuleContext() antlr.RuleContext
- func (*EdgeRHSContext) IsEdgeRHSContext()
- func (s *EdgeRHSContext) Node_id(i int) INode_idContext
- func (s *EdgeRHSContext) Subgraph(i int) ISubgraphContext
- func (s *EdgeRHSContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type Edge_stmtContext
- func (s *Edge_stmtContext) Attr_list() IAttr_listContext
- func (s *Edge_stmtContext) EdgeRHS() IEdgeRHSContext
- func (s *Edge_stmtContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *Edge_stmtContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *Edge_stmtContext) GetParser() antlr.Parser
- func (s *Edge_stmtContext) GetRuleContext() antlr.RuleContext
- func (*Edge_stmtContext) IsEdge_stmtContext()
- func (s *Edge_stmtContext) Node_id() INode_idContext
- func (s *Edge_stmtContext) Subgraph() ISubgraphContext
- func (s *Edge_stmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type EdgeopContext
- func (s *EdgeopContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *EdgeopContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *EdgeopContext) GetParser() antlr.Parser
- func (s *EdgeopContext) GetRuleContext() antlr.RuleContext
- func (*EdgeopContext) IsEdgeopContext()
- func (s *EdgeopContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type GraphContext
- func (s *GraphContext) DIGRAPH() antlr.TerminalNode
- func (s *GraphContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *GraphContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *GraphContext) GRAPH() antlr.TerminalNode
- func (s *GraphContext) GetParser() antlr.Parser
- func (s *GraphContext) GetRuleContext() antlr.RuleContext
- func (s *GraphContext) Id() IIdContext
- func (*GraphContext) IsGraphContext()
- func (s *GraphContext) STRICT() antlr.TerminalNode
- func (s *GraphContext) Stmt_list() IStmt_listContext
- func (s *GraphContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type IA_listContext
- type IAttr_listContext
- type IAttr_stmtContext
- type IEdgeRHSContext
- type IEdge_stmtContext
- type IEdgeopContext
- type IGraphContext
- type IIdContext
- type INode_idContext
- type INode_stmtContext
- type IPortContext
- type IStmtContext
- type IStmt_listContext
- type ISubgraphContext
- type IdContext
- func (s *IdContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *IdContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *IdContext) GetParser() antlr.Parser
- func (s *IdContext) GetRuleContext() antlr.RuleContext
- func (s *IdContext) HTML_STRING() antlr.TerminalNode
- func (s *IdContext) ID() antlr.TerminalNode
- func (*IdContext) IsIdContext()
- func (s *IdContext) NUMBER() antlr.TerminalNode
- func (s *IdContext) STRING() antlr.TerminalNode
- func (s *IdContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type Node_idContext
- func (s *Node_idContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *Node_idContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *Node_idContext) GetParser() antlr.Parser
- func (s *Node_idContext) GetRuleContext() antlr.RuleContext
- func (s *Node_idContext) Id() IIdContext
- func (*Node_idContext) IsNode_idContext()
- func (s *Node_idContext) Port() IPortContext
- func (s *Node_idContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type Node_stmtContext
- func (s *Node_stmtContext) Attr_list() IAttr_listContext
- func (s *Node_stmtContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *Node_stmtContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *Node_stmtContext) GetParser() antlr.Parser
- func (s *Node_stmtContext) GetRuleContext() antlr.RuleContext
- func (*Node_stmtContext) IsNode_stmtContext()
- func (s *Node_stmtContext) Node_id() INode_idContext
- func (s *Node_stmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type PortContext
- func (s *PortContext) AllId() []IIdContext
- func (s *PortContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *PortContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *PortContext) GetParser() antlr.Parser
- func (s *PortContext) GetRuleContext() antlr.RuleContext
- func (s *PortContext) Id(i int) IIdContext
- func (*PortContext) IsPortContext()
- func (s *PortContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type StmtContext
- func (s *StmtContext) AllId() []IIdContext
- func (s *StmtContext) Attr_stmt() IAttr_stmtContext
- func (s *StmtContext) Edge_stmt() IEdge_stmtContext
- func (s *StmtContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *StmtContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *StmtContext) GetParser() antlr.Parser
- func (s *StmtContext) GetRuleContext() antlr.RuleContext
- func (s *StmtContext) Id(i int) IIdContext
- func (*StmtContext) IsStmtContext()
- func (s *StmtContext) Node_stmt() INode_stmtContext
- func (s *StmtContext) Subgraph() ISubgraphContext
- func (s *StmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type Stmt_listContext
- func (s *Stmt_listContext) AllStmt() []IStmtContext
- func (s *Stmt_listContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *Stmt_listContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *Stmt_listContext) GetParser() antlr.Parser
- func (s *Stmt_listContext) GetRuleContext() antlr.RuleContext
- func (*Stmt_listContext) IsStmt_listContext()
- func (s *Stmt_listContext) Stmt(i int) IStmtContext
- func (s *Stmt_listContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
- type SubgraphContext
- func (s *SubgraphContext) EnterRule(listener antlr.ParseTreeListener)
- func (s *SubgraphContext) ExitRule(listener antlr.ParseTreeListener)
- func (s *SubgraphContext) GetParser() antlr.Parser
- func (s *SubgraphContext) GetRuleContext() antlr.RuleContext
- func (s *SubgraphContext) Id() IIdContext
- func (*SubgraphContext) IsSubgraphContext()
- func (s *SubgraphContext) SUBGRAPH() antlr.TerminalNode
- func (s *SubgraphContext) Stmt_list() IStmt_listContext
- func (s *SubgraphContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
Examples ¶
Constants ¶
const ( DOTLexerT__0 = 1 DOTLexerT__1 = 2 DOTLexerT__2 = 3 DOTLexerT__3 = 4 DOTLexerT__4 = 5 DOTLexerT__5 = 6 DOTLexerT__6 = 7 DOTLexerT__7 = 8 DOTLexerT__8 = 9 DOTLexerT__9 = 10 DOTLexerSTRICT = 11 DOTLexerGRAPH = 12 DOTLexerDIGRAPH = 13 DOTLexerNODE = 14 DOTLexerEDGE = 15 DOTLexerSUBGRAPH = 16 DOTLexerNUMBER = 17 DOTLexerSTRING = 18 DOTLexerID = 19 DOTLexerHTML_STRING = 20 DOTLexerCOMMENT = 21 DOTLexerLINE_COMMENT = 22 DOTLexerPREPROC = 23 DOTLexerWS = 24 )
DOTLexer tokens.
const ( DOTParserEOF = antlr.TokenEOF DOTParserT__0 = 1 DOTParserT__1 = 2 DOTParserT__2 = 3 DOTParserT__3 = 4 DOTParserT__4 = 5 DOTParserT__5 = 6 DOTParserT__6 = 7 DOTParserT__7 = 8 DOTParserT__8 = 9 DOTParserT__9 = 10 DOTParserSTRICT = 11 DOTParserGRAPH = 12 DOTParserDIGRAPH = 13 DOTParserNODE = 14 DOTParserEDGE = 15 DOTParserSUBGRAPH = 16 DOTParserNUMBER = 17 DOTParserSTRING = 18 DOTParserID = 19 DOTParserHTML_STRING = 20 DOTParserCOMMENT = 21 DOTParserLINE_COMMENT = 22 DOTParserPREPROC = 23 DOTParserWS = 24 )
DOTParser tokens.
const ( DOTParserRULE_graph = 0 DOTParserRULE_stmt_list = 1 DOTParserRULE_stmt = 2 DOTParserRULE_attr_stmt = 3 DOTParserRULE_attr_list = 4 DOTParserRULE_a_list = 5 DOTParserRULE_edge_stmt = 6 DOTParserRULE_edgeRHS = 7 DOTParserRULE_edgeop = 8 DOTParserRULE_node_stmt = 9 DOTParserRULE_node_id = 10 DOTParserRULE_port = 11 DOTParserRULE_subgraph = 12 DOTParserRULE_id = 13 )
DOTParser rules.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type A_listContext ¶
type A_listContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewA_listContext ¶
func NewA_listContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *A_listContext
func NewEmptyA_listContext ¶
func NewEmptyA_listContext() *A_listContext
func (*A_listContext) AllId ¶
func (s *A_listContext) AllId() []IIdContext
func (*A_listContext) EnterRule ¶
func (s *A_listContext) EnterRule(listener antlr.ParseTreeListener)
func (*A_listContext) ExitRule ¶
func (s *A_listContext) ExitRule(listener antlr.ParseTreeListener)
func (*A_listContext) GetParser ¶
func (s *A_listContext) GetParser() antlr.Parser
func (*A_listContext) GetRuleContext ¶
func (s *A_listContext) GetRuleContext() antlr.RuleContext
func (*A_listContext) Id ¶
func (s *A_listContext) Id(i int) IIdContext
func (*A_listContext) IsA_listContext ¶
func (*A_listContext) IsA_listContext()
func (*A_listContext) ToStringTree ¶
func (s *A_listContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type Attr_listContext ¶
type Attr_listContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewAttr_listContext ¶
func NewAttr_listContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *Attr_listContext
func NewEmptyAttr_listContext ¶
func NewEmptyAttr_listContext() *Attr_listContext
func (*Attr_listContext) A_list ¶
func (s *Attr_listContext) A_list(i int) IA_listContext
func (*Attr_listContext) AllA_list ¶
func (s *Attr_listContext) AllA_list() []IA_listContext
func (*Attr_listContext) EnterRule ¶
func (s *Attr_listContext) EnterRule(listener antlr.ParseTreeListener)
func (*Attr_listContext) ExitRule ¶
func (s *Attr_listContext) ExitRule(listener antlr.ParseTreeListener)
func (*Attr_listContext) GetParser ¶
func (s *Attr_listContext) GetParser() antlr.Parser
func (*Attr_listContext) GetRuleContext ¶
func (s *Attr_listContext) GetRuleContext() antlr.RuleContext
func (*Attr_listContext) IsAttr_listContext ¶
func (*Attr_listContext) IsAttr_listContext()
func (*Attr_listContext) ToStringTree ¶
func (s *Attr_listContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type Attr_stmtContext ¶
type Attr_stmtContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewAttr_stmtContext ¶
func NewAttr_stmtContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *Attr_stmtContext
func NewEmptyAttr_stmtContext ¶
func NewEmptyAttr_stmtContext() *Attr_stmtContext
func (*Attr_stmtContext) Attr_list ¶
func (s *Attr_stmtContext) Attr_list() IAttr_listContext
func (*Attr_stmtContext) EDGE ¶
func (s *Attr_stmtContext) EDGE() antlr.TerminalNode
func (*Attr_stmtContext) EnterRule ¶
func (s *Attr_stmtContext) EnterRule(listener antlr.ParseTreeListener)
func (*Attr_stmtContext) ExitRule ¶
func (s *Attr_stmtContext) ExitRule(listener antlr.ParseTreeListener)
func (*Attr_stmtContext) GRAPH ¶
func (s *Attr_stmtContext) GRAPH() antlr.TerminalNode
func (*Attr_stmtContext) GetParser ¶
func (s *Attr_stmtContext) GetParser() antlr.Parser
func (*Attr_stmtContext) GetRuleContext ¶
func (s *Attr_stmtContext) GetRuleContext() antlr.RuleContext
func (*Attr_stmtContext) IsAttr_stmtContext ¶
func (*Attr_stmtContext) IsAttr_stmtContext()
func (*Attr_stmtContext) NODE ¶
func (s *Attr_stmtContext) NODE() antlr.TerminalNode
func (*Attr_stmtContext) ToStringTree ¶
func (s *Attr_stmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type BaseDOTListener ¶
type BaseDOTListener struct{}
BaseDOTListener is a complete listener for a parse tree produced by DOTParser.
func (*BaseDOTListener) EnterA_list ¶
func (s *BaseDOTListener) EnterA_list(ctx *A_listContext)
EnterA_list is called when production a_list is entered.
func (*BaseDOTListener) EnterAttr_list ¶
func (s *BaseDOTListener) EnterAttr_list(ctx *Attr_listContext)
EnterAttr_list is called when production attr_list is entered.
func (*BaseDOTListener) EnterAttr_stmt ¶
func (s *BaseDOTListener) EnterAttr_stmt(ctx *Attr_stmtContext)
EnterAttr_stmt is called when production attr_stmt is entered.
func (*BaseDOTListener) EnterEdgeRHS ¶
func (s *BaseDOTListener) EnterEdgeRHS(ctx *EdgeRHSContext)
EnterEdgeRHS is called when production edgeRHS is entered.
func (*BaseDOTListener) EnterEdge_stmt ¶
func (s *BaseDOTListener) EnterEdge_stmt(ctx *Edge_stmtContext)
EnterEdge_stmt is called when production edge_stmt is entered.
func (*BaseDOTListener) EnterEdgeop ¶
func (s *BaseDOTListener) EnterEdgeop(ctx *EdgeopContext)
EnterEdgeop is called when production edgeop is entered.
func (*BaseDOTListener) EnterEveryRule ¶
func (s *BaseDOTListener) EnterEveryRule(ctx antlr.ParserRuleContext)
EnterEveryRule is called when any rule is entered.
func (*BaseDOTListener) EnterGraph ¶
func (s *BaseDOTListener) EnterGraph(ctx *GraphContext)
EnterGraph is called when production graph is entered.
func (*BaseDOTListener) EnterId ¶
func (s *BaseDOTListener) EnterId(ctx *IdContext)
EnterId is called when production id is entered.
func (*BaseDOTListener) EnterNode_id ¶
func (s *BaseDOTListener) EnterNode_id(ctx *Node_idContext)
EnterNode_id is called when production node_id is entered.
func (*BaseDOTListener) EnterNode_stmt ¶
func (s *BaseDOTListener) EnterNode_stmt(ctx *Node_stmtContext)
EnterNode_stmt is called when production node_stmt is entered.
func (*BaseDOTListener) EnterPort ¶
func (s *BaseDOTListener) EnterPort(ctx *PortContext)
EnterPort is called when production port is entered.
func (*BaseDOTListener) EnterStmt ¶
func (s *BaseDOTListener) EnterStmt(ctx *StmtContext)
EnterStmt is called when production stmt is entered.
func (*BaseDOTListener) EnterStmt_list ¶
func (s *BaseDOTListener) EnterStmt_list(ctx *Stmt_listContext)
EnterStmt_list is called when production stmt_list is entered.
func (*BaseDOTListener) EnterSubgraph ¶
func (s *BaseDOTListener) EnterSubgraph(ctx *SubgraphContext)
EnterSubgraph is called when production subgraph is entered.
func (*BaseDOTListener) ExitA_list ¶
func (s *BaseDOTListener) ExitA_list(ctx *A_listContext)
ExitA_list is called when production a_list is exited.
func (*BaseDOTListener) ExitAttr_list ¶
func (s *BaseDOTListener) ExitAttr_list(ctx *Attr_listContext)
ExitAttr_list is called when production attr_list is exited.
func (*BaseDOTListener) ExitAttr_stmt ¶
func (s *BaseDOTListener) ExitAttr_stmt(ctx *Attr_stmtContext)
ExitAttr_stmt is called when production attr_stmt is exited.
func (*BaseDOTListener) ExitEdgeRHS ¶
func (s *BaseDOTListener) ExitEdgeRHS(ctx *EdgeRHSContext)
ExitEdgeRHS is called when production edgeRHS is exited.
func (*BaseDOTListener) ExitEdge_stmt ¶
func (s *BaseDOTListener) ExitEdge_stmt(ctx *Edge_stmtContext)
ExitEdge_stmt is called when production edge_stmt is exited.
func (*BaseDOTListener) ExitEdgeop ¶
func (s *BaseDOTListener) ExitEdgeop(ctx *EdgeopContext)
ExitEdgeop is called when production edgeop is exited.
func (*BaseDOTListener) ExitEveryRule ¶
func (s *BaseDOTListener) ExitEveryRule(ctx antlr.ParserRuleContext)
ExitEveryRule is called when any rule is exited.
func (*BaseDOTListener) ExitGraph ¶
func (s *BaseDOTListener) ExitGraph(ctx *GraphContext)
ExitGraph is called when production graph is exited.
func (*BaseDOTListener) ExitId ¶
func (s *BaseDOTListener) ExitId(ctx *IdContext)
ExitId is called when production id is exited.
func (*BaseDOTListener) ExitNode_id ¶
func (s *BaseDOTListener) ExitNode_id(ctx *Node_idContext)
ExitNode_id is called when production node_id is exited.
func (*BaseDOTListener) ExitNode_stmt ¶
func (s *BaseDOTListener) ExitNode_stmt(ctx *Node_stmtContext)
ExitNode_stmt is called when production node_stmt is exited.
func (*BaseDOTListener) ExitPort ¶
func (s *BaseDOTListener) ExitPort(ctx *PortContext)
ExitPort is called when production port is exited.
func (*BaseDOTListener) ExitStmt ¶
func (s *BaseDOTListener) ExitStmt(ctx *StmtContext)
ExitStmt is called when production stmt is exited.
func (*BaseDOTListener) ExitStmt_list ¶
func (s *BaseDOTListener) ExitStmt_list(ctx *Stmt_listContext)
ExitStmt_list is called when production stmt_list is exited.
func (*BaseDOTListener) ExitSubgraph ¶
func (s *BaseDOTListener) ExitSubgraph(ctx *SubgraphContext)
ExitSubgraph is called when production subgraph is exited.
func (*BaseDOTListener) VisitErrorNode ¶
func (s *BaseDOTListener) VisitErrorNode(node antlr.ErrorNode)
VisitErrorNode is called when an error node is visited.
func (*BaseDOTListener) VisitTerminal ¶
func (s *BaseDOTListener) VisitTerminal(node antlr.TerminalNode)
VisitTerminal is called when a terminal node is visited.
type DOTLexer ¶
func NewDOTLexer ¶
func NewDOTLexer(input antlr.CharStream) *DOTLexer
type DOTListener ¶
type DOTListener interface {
antlr.ParseTreeListener
// EnterGraph is called when entering the graph production.
EnterGraph(c *GraphContext)
// EnterStmt_list is called when entering the stmt_list production.
EnterStmt_list(c *Stmt_listContext)
// EnterStmt is called when entering the stmt production.
EnterStmt(c *StmtContext)
// EnterAttr_stmt is called when entering the attr_stmt production.
EnterAttr_stmt(c *Attr_stmtContext)
// EnterAttr_list is called when entering the attr_list production.
EnterAttr_list(c *Attr_listContext)
// EnterA_list is called when entering the a_list production.
EnterA_list(c *A_listContext)
// EnterEdge_stmt is called when entering the edge_stmt production.
EnterEdge_stmt(c *Edge_stmtContext)
// EnterEdgeRHS is called when entering the edgeRHS production.
EnterEdgeRHS(c *EdgeRHSContext)
// EnterEdgeop is called when entering the edgeop production.
EnterEdgeop(c *EdgeopContext)
// EnterNode_stmt is called when entering the node_stmt production.
EnterNode_stmt(c *Node_stmtContext)
// EnterNode_id is called when entering the node_id production.
EnterNode_id(c *Node_idContext)
// EnterPort is called when entering the port production.
EnterPort(c *PortContext)
// EnterSubgraph is called when entering the subgraph production.
EnterSubgraph(c *SubgraphContext)
// EnterId is called when entering the id production.
EnterId(c *IdContext)
// ExitGraph is called when exiting the graph production.
ExitGraph(c *GraphContext)
// ExitStmt_list is called when exiting the stmt_list production.
ExitStmt_list(c *Stmt_listContext)
// ExitStmt is called when exiting the stmt production.
ExitStmt(c *StmtContext)
// ExitAttr_stmt is called when exiting the attr_stmt production.
ExitAttr_stmt(c *Attr_stmtContext)
// ExitAttr_list is called when exiting the attr_list production.
ExitAttr_list(c *Attr_listContext)
// ExitA_list is called when exiting the a_list production.
ExitA_list(c *A_listContext)
// ExitEdge_stmt is called when exiting the edge_stmt production.
ExitEdge_stmt(c *Edge_stmtContext)
// ExitEdgeRHS is called when exiting the edgeRHS production.
ExitEdgeRHS(c *EdgeRHSContext)
// ExitEdgeop is called when exiting the edgeop production.
ExitEdgeop(c *EdgeopContext)
// ExitNode_stmt is called when exiting the node_stmt production.
ExitNode_stmt(c *Node_stmtContext)
// ExitNode_id is called when exiting the node_id production.
ExitNode_id(c *Node_idContext)
// ExitPort is called when exiting the port production.
ExitPort(c *PortContext)
// ExitSubgraph is called when exiting the subgraph production.
ExitSubgraph(c *SubgraphContext)
// ExitId is called when exiting the id production.
ExitId(c *IdContext)
}
DOTListener is a complete listener for a parse tree produced by DOTParser.
type DOTParser ¶
type DOTParser struct {
*antlr.BaseParser
}
func NewDOTParser ¶
func NewDOTParser(input antlr.TokenStream) *DOTParser
func (*DOTParser) A_list ¶
func (p *DOTParser) A_list() (localctx IA_listContext)
func (*DOTParser) Attr_list ¶
func (p *DOTParser) Attr_list() (localctx IAttr_listContext)
func (*DOTParser) Attr_stmt ¶
func (p *DOTParser) Attr_stmt() (localctx IAttr_stmtContext)
func (*DOTParser) EdgeRHS ¶
func (p *DOTParser) EdgeRHS() (localctx IEdgeRHSContext)
func (*DOTParser) Edge_stmt ¶
func (p *DOTParser) Edge_stmt() (localctx IEdge_stmtContext)
func (*DOTParser) Edgeop ¶
func (p *DOTParser) Edgeop() (localctx IEdgeopContext)
func (*DOTParser) Graph ¶
func (p *DOTParser) Graph() (localctx IGraphContext)
func (*DOTParser) Id ¶
func (p *DOTParser) Id() (localctx IIdContext)
func (*DOTParser) Node_id ¶
func (p *DOTParser) Node_id() (localctx INode_idContext)
func (*DOTParser) Node_stmt ¶
func (p *DOTParser) Node_stmt() (localctx INode_stmtContext)
func (*DOTParser) Port ¶
func (p *DOTParser) Port() (localctx IPortContext)
func (*DOTParser) Stmt ¶
func (p *DOTParser) Stmt() (localctx IStmtContext)
func (*DOTParser) Stmt_list ¶
func (p *DOTParser) Stmt_list() (localctx IStmt_listContext)
func (*DOTParser) Subgraph ¶
func (p *DOTParser) Subgraph() (localctx ISubgraphContext)
type EdgeRHSContext ¶
type EdgeRHSContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEdgeRHSContext ¶
func NewEdgeRHSContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *EdgeRHSContext
func NewEmptyEdgeRHSContext ¶
func NewEmptyEdgeRHSContext() *EdgeRHSContext
func (*EdgeRHSContext) AllEdgeop ¶
func (s *EdgeRHSContext) AllEdgeop() []IEdgeopContext
func (*EdgeRHSContext) AllNode_id ¶
func (s *EdgeRHSContext) AllNode_id() []INode_idContext
func (*EdgeRHSContext) AllSubgraph ¶
func (s *EdgeRHSContext) AllSubgraph() []ISubgraphContext
func (*EdgeRHSContext) Edgeop ¶
func (s *EdgeRHSContext) Edgeop(i int) IEdgeopContext
func (*EdgeRHSContext) EnterRule ¶
func (s *EdgeRHSContext) EnterRule(listener antlr.ParseTreeListener)
func (*EdgeRHSContext) ExitRule ¶
func (s *EdgeRHSContext) ExitRule(listener antlr.ParseTreeListener)
func (*EdgeRHSContext) GetParser ¶
func (s *EdgeRHSContext) GetParser() antlr.Parser
func (*EdgeRHSContext) GetRuleContext ¶
func (s *EdgeRHSContext) GetRuleContext() antlr.RuleContext
func (*EdgeRHSContext) IsEdgeRHSContext ¶
func (*EdgeRHSContext) IsEdgeRHSContext()
func (*EdgeRHSContext) Node_id ¶
func (s *EdgeRHSContext) Node_id(i int) INode_idContext
func (*EdgeRHSContext) Subgraph ¶
func (s *EdgeRHSContext) Subgraph(i int) ISubgraphContext
func (*EdgeRHSContext) ToStringTree ¶
func (s *EdgeRHSContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type Edge_stmtContext ¶
type Edge_stmtContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEdge_stmtContext ¶
func NewEdge_stmtContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *Edge_stmtContext
func NewEmptyEdge_stmtContext ¶
func NewEmptyEdge_stmtContext() *Edge_stmtContext
func (*Edge_stmtContext) Attr_list ¶
func (s *Edge_stmtContext) Attr_list() IAttr_listContext
func (*Edge_stmtContext) EdgeRHS ¶
func (s *Edge_stmtContext) EdgeRHS() IEdgeRHSContext
func (*Edge_stmtContext) EnterRule ¶
func (s *Edge_stmtContext) EnterRule(listener antlr.ParseTreeListener)
func (*Edge_stmtContext) ExitRule ¶
func (s *Edge_stmtContext) ExitRule(listener antlr.ParseTreeListener)
func (*Edge_stmtContext) GetParser ¶
func (s *Edge_stmtContext) GetParser() antlr.Parser
func (*Edge_stmtContext) GetRuleContext ¶
func (s *Edge_stmtContext) GetRuleContext() antlr.RuleContext
func (*Edge_stmtContext) IsEdge_stmtContext ¶
func (*Edge_stmtContext) IsEdge_stmtContext()
func (*Edge_stmtContext) Node_id ¶
func (s *Edge_stmtContext) Node_id() INode_idContext
func (*Edge_stmtContext) Subgraph ¶
func (s *Edge_stmtContext) Subgraph() ISubgraphContext
func (*Edge_stmtContext) ToStringTree ¶
func (s *Edge_stmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type EdgeopContext ¶
type EdgeopContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEdgeopContext ¶
func NewEdgeopContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *EdgeopContext
func NewEmptyEdgeopContext ¶
func NewEmptyEdgeopContext() *EdgeopContext
func (*EdgeopContext) EnterRule ¶
func (s *EdgeopContext) EnterRule(listener antlr.ParseTreeListener)
func (*EdgeopContext) ExitRule ¶
func (s *EdgeopContext) ExitRule(listener antlr.ParseTreeListener)
func (*EdgeopContext) GetParser ¶
func (s *EdgeopContext) GetParser() antlr.Parser
func (*EdgeopContext) GetRuleContext ¶
func (s *EdgeopContext) GetRuleContext() antlr.RuleContext
func (*EdgeopContext) IsEdgeopContext ¶
func (*EdgeopContext) IsEdgeopContext()
func (*EdgeopContext) ToStringTree ¶
func (s *EdgeopContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type GraphContext ¶
type GraphContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyGraphContext ¶
func NewEmptyGraphContext() *GraphContext
func NewGraphContext ¶
func NewGraphContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *GraphContext
func (*GraphContext) DIGRAPH ¶
func (s *GraphContext) DIGRAPH() antlr.TerminalNode
func (*GraphContext) EnterRule ¶
func (s *GraphContext) EnterRule(listener antlr.ParseTreeListener)
func (*GraphContext) ExitRule ¶
func (s *GraphContext) ExitRule(listener antlr.ParseTreeListener)
func (*GraphContext) GRAPH ¶
func (s *GraphContext) GRAPH() antlr.TerminalNode
func (*GraphContext) GetParser ¶
func (s *GraphContext) GetParser() antlr.Parser
func (*GraphContext) GetRuleContext ¶
func (s *GraphContext) GetRuleContext() antlr.RuleContext
func (*GraphContext) Id ¶
func (s *GraphContext) Id() IIdContext
func (*GraphContext) IsGraphContext ¶
func (*GraphContext) IsGraphContext()
func (*GraphContext) STRICT ¶
func (s *GraphContext) STRICT() antlr.TerminalNode
func (*GraphContext) Stmt_list ¶
func (s *GraphContext) Stmt_list() IStmt_listContext
func (*GraphContext) ToStringTree ¶
func (s *GraphContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type IA_listContext ¶
type IA_listContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsA_listContext differentiates from other interfaces.
IsA_listContext()
}
IA_listContext is an interface to support dynamic dispatch.
type IAttr_listContext ¶
type IAttr_listContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsAttr_listContext differentiates from other interfaces.
IsAttr_listContext()
}
IAttr_listContext is an interface to support dynamic dispatch.
type IAttr_stmtContext ¶
type IAttr_stmtContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsAttr_stmtContext differentiates from other interfaces.
IsAttr_stmtContext()
}
IAttr_stmtContext is an interface to support dynamic dispatch.
type IEdgeRHSContext ¶
type IEdgeRHSContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsEdgeRHSContext differentiates from other interfaces.
IsEdgeRHSContext()
}
IEdgeRHSContext is an interface to support dynamic dispatch.
type IEdge_stmtContext ¶
type IEdge_stmtContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsEdge_stmtContext differentiates from other interfaces.
IsEdge_stmtContext()
}
IEdge_stmtContext is an interface to support dynamic dispatch.
type IEdgeopContext ¶
type IEdgeopContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsEdgeopContext differentiates from other interfaces.
IsEdgeopContext()
}
IEdgeopContext is an interface to support dynamic dispatch.
type IGraphContext ¶
type IGraphContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsGraphContext differentiates from other interfaces.
IsGraphContext()
}
IGraphContext is an interface to support dynamic dispatch.
type IIdContext ¶
type IIdContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsIdContext differentiates from other interfaces.
IsIdContext()
}
IIdContext is an interface to support dynamic dispatch.
type INode_idContext ¶
type INode_idContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsNode_idContext differentiates from other interfaces.
IsNode_idContext()
}
INode_idContext is an interface to support dynamic dispatch.
type INode_stmtContext ¶
type INode_stmtContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsNode_stmtContext differentiates from other interfaces.
IsNode_stmtContext()
}
INode_stmtContext is an interface to support dynamic dispatch.
type IPortContext ¶
type IPortContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsPortContext differentiates from other interfaces.
IsPortContext()
}
IPortContext is an interface to support dynamic dispatch.
type IStmtContext ¶
type IStmtContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsStmtContext differentiates from other interfaces.
IsStmtContext()
}
IStmtContext is an interface to support dynamic dispatch.
type IStmt_listContext ¶
type IStmt_listContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsStmt_listContext differentiates from other interfaces.
IsStmt_listContext()
}
IStmt_listContext is an interface to support dynamic dispatch.
type ISubgraphContext ¶
type ISubgraphContext interface {
antlr.ParserRuleContext
// GetParser returns the parser.
GetParser() antlr.Parser
// IsSubgraphContext differentiates from other interfaces.
IsSubgraphContext()
}
ISubgraphContext is an interface to support dynamic dispatch.
type IdContext ¶
type IdContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyIdContext ¶
func NewEmptyIdContext() *IdContext
func NewIdContext ¶
func (*IdContext) EnterRule ¶
func (s *IdContext) EnterRule(listener antlr.ParseTreeListener)
func (*IdContext) ExitRule ¶
func (s *IdContext) ExitRule(listener antlr.ParseTreeListener)
func (*IdContext) GetRuleContext ¶
func (s *IdContext) GetRuleContext() antlr.RuleContext
func (*IdContext) HTML_STRING ¶
func (s *IdContext) HTML_STRING() antlr.TerminalNode
func (*IdContext) ID ¶
func (s *IdContext) ID() antlr.TerminalNode
func (*IdContext) IsIdContext ¶
func (*IdContext) IsIdContext()
func (*IdContext) NUMBER ¶
func (s *IdContext) NUMBER() antlr.TerminalNode
func (*IdContext) STRING ¶
func (s *IdContext) STRING() antlr.TerminalNode
func (*IdContext) ToStringTree ¶
func (s *IdContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type Node_idContext ¶
type Node_idContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyNode_idContext ¶
func NewEmptyNode_idContext() *Node_idContext
func NewNode_idContext ¶
func NewNode_idContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *Node_idContext
func (*Node_idContext) EnterRule ¶
func (s *Node_idContext) EnterRule(listener antlr.ParseTreeListener)
func (*Node_idContext) ExitRule ¶
func (s *Node_idContext) ExitRule(listener antlr.ParseTreeListener)
func (*Node_idContext) GetParser ¶
func (s *Node_idContext) GetParser() antlr.Parser
func (*Node_idContext) GetRuleContext ¶
func (s *Node_idContext) GetRuleContext() antlr.RuleContext
func (*Node_idContext) Id ¶
func (s *Node_idContext) Id() IIdContext
func (*Node_idContext) IsNode_idContext ¶
func (*Node_idContext) IsNode_idContext()
func (*Node_idContext) Port ¶
func (s *Node_idContext) Port() IPortContext
func (*Node_idContext) ToStringTree ¶
func (s *Node_idContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type Node_stmtContext ¶
type Node_stmtContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyNode_stmtContext ¶
func NewEmptyNode_stmtContext() *Node_stmtContext
func NewNode_stmtContext ¶
func NewNode_stmtContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *Node_stmtContext
func (*Node_stmtContext) Attr_list ¶
func (s *Node_stmtContext) Attr_list() IAttr_listContext
func (*Node_stmtContext) EnterRule ¶
func (s *Node_stmtContext) EnterRule(listener antlr.ParseTreeListener)
func (*Node_stmtContext) ExitRule ¶
func (s *Node_stmtContext) ExitRule(listener antlr.ParseTreeListener)
func (*Node_stmtContext) GetParser ¶
func (s *Node_stmtContext) GetParser() antlr.Parser
func (*Node_stmtContext) GetRuleContext ¶
func (s *Node_stmtContext) GetRuleContext() antlr.RuleContext
func (*Node_stmtContext) IsNode_stmtContext ¶
func (*Node_stmtContext) IsNode_stmtContext()
func (*Node_stmtContext) Node_id ¶
func (s *Node_stmtContext) Node_id() INode_idContext
func (*Node_stmtContext) ToStringTree ¶
func (s *Node_stmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type PortContext ¶
type PortContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyPortContext ¶
func NewEmptyPortContext() *PortContext
func NewPortContext ¶
func NewPortContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *PortContext
func (*PortContext) AllId ¶
func (s *PortContext) AllId() []IIdContext
func (*PortContext) EnterRule ¶
func (s *PortContext) EnterRule(listener antlr.ParseTreeListener)
func (*PortContext) ExitRule ¶
func (s *PortContext) ExitRule(listener antlr.ParseTreeListener)
func (*PortContext) GetParser ¶
func (s *PortContext) GetParser() antlr.Parser
func (*PortContext) GetRuleContext ¶
func (s *PortContext) GetRuleContext() antlr.RuleContext
func (*PortContext) Id ¶
func (s *PortContext) Id(i int) IIdContext
func (*PortContext) IsPortContext ¶
func (*PortContext) IsPortContext()
func (*PortContext) ToStringTree ¶
func (s *PortContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type StmtContext ¶
type StmtContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyStmtContext ¶
func NewEmptyStmtContext() *StmtContext
func NewStmtContext ¶
func NewStmtContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *StmtContext
func (*StmtContext) AllId ¶
func (s *StmtContext) AllId() []IIdContext
func (*StmtContext) Attr_stmt ¶
func (s *StmtContext) Attr_stmt() IAttr_stmtContext
func (*StmtContext) Edge_stmt ¶
func (s *StmtContext) Edge_stmt() IEdge_stmtContext
func (*StmtContext) EnterRule ¶
func (s *StmtContext) EnterRule(listener antlr.ParseTreeListener)
func (*StmtContext) ExitRule ¶
func (s *StmtContext) ExitRule(listener antlr.ParseTreeListener)
func (*StmtContext) GetParser ¶
func (s *StmtContext) GetParser() antlr.Parser
func (*StmtContext) GetRuleContext ¶
func (s *StmtContext) GetRuleContext() antlr.RuleContext
func (*StmtContext) Id ¶
func (s *StmtContext) Id(i int) IIdContext
func (*StmtContext) IsStmtContext ¶
func (*StmtContext) IsStmtContext()
func (*StmtContext) Node_stmt ¶
func (s *StmtContext) Node_stmt() INode_stmtContext
func (*StmtContext) Subgraph ¶
func (s *StmtContext) Subgraph() ISubgraphContext
func (*StmtContext) ToStringTree ¶
func (s *StmtContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type Stmt_listContext ¶
type Stmt_listContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptyStmt_listContext ¶
func NewEmptyStmt_listContext() *Stmt_listContext
func NewStmt_listContext ¶
func NewStmt_listContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *Stmt_listContext
func (*Stmt_listContext) AllStmt ¶
func (s *Stmt_listContext) AllStmt() []IStmtContext
func (*Stmt_listContext) EnterRule ¶
func (s *Stmt_listContext) EnterRule(listener antlr.ParseTreeListener)
func (*Stmt_listContext) ExitRule ¶
func (s *Stmt_listContext) ExitRule(listener antlr.ParseTreeListener)
func (*Stmt_listContext) GetParser ¶
func (s *Stmt_listContext) GetParser() antlr.Parser
func (*Stmt_listContext) GetRuleContext ¶
func (s *Stmt_listContext) GetRuleContext() antlr.RuleContext
func (*Stmt_listContext) IsStmt_listContext ¶
func (*Stmt_listContext) IsStmt_listContext()
func (*Stmt_listContext) Stmt ¶
func (s *Stmt_listContext) Stmt(i int) IStmtContext
func (*Stmt_listContext) ToStringTree ¶
func (s *Stmt_listContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string
type SubgraphContext ¶
type SubgraphContext struct {
*antlr.BaseParserRuleContext
// contains filtered or unexported fields
}
func NewEmptySubgraphContext ¶
func NewEmptySubgraphContext() *SubgraphContext
func NewSubgraphContext ¶
func NewSubgraphContext(parser antlr.Parser, parent antlr.ParserRuleContext, invokingState int) *SubgraphContext
func (*SubgraphContext) EnterRule ¶
func (s *SubgraphContext) EnterRule(listener antlr.ParseTreeListener)
func (*SubgraphContext) ExitRule ¶
func (s *SubgraphContext) ExitRule(listener antlr.ParseTreeListener)
func (*SubgraphContext) GetParser ¶
func (s *SubgraphContext) GetParser() antlr.Parser
func (*SubgraphContext) GetRuleContext ¶
func (s *SubgraphContext) GetRuleContext() antlr.RuleContext
func (*SubgraphContext) Id ¶
func (s *SubgraphContext) Id() IIdContext
func (*SubgraphContext) IsSubgraphContext ¶
func (*SubgraphContext) IsSubgraphContext()
func (*SubgraphContext) SUBGRAPH ¶
func (s *SubgraphContext) SUBGRAPH() antlr.TerminalNode
func (*SubgraphContext) Stmt_list ¶
func (s *SubgraphContext) Stmt_list() IStmt_listContext
func (*SubgraphContext) ToStringTree ¶
func (s *SubgraphContext) ToStringTree(ruleNames []string, recog antlr.Recognizer) string